<?php
$lang['import_completed'] = 'Import vollst&auml;ndig';
$lang['num_imported'] = 'Anzahl der eingetragenen Termine: %d';
$lang['import_lines'] = 'Anzahl der aus der Datei verarbeiteten Zeilen: %d';
$lang['errors'] = 'Fehler';
$lang['error_csvfirstlineinvalidfield'] = 'Feld: %s is not recognized, and is not a custom field';
$lang['info_csv_format'] = '<h4>CSV File Format Information.</h4>
<ul>
  <li>General Information:
   <ul>
     <li>The file must be an ASCII file with unix, dos, or (hopefully) mac line endings.</li>
     <li>Comments start with // any characters after this on a line will be ignored (including within quotes.</li>
     <li>Empty lines are ignore.d</li>
     <li>Fields are delimited with a , however a , can be used as a value within a field if the field is delimited by double quotes.</li>
     <li>Rows are delimited by newline chars (as above).</li>
   </ul>
  </li>
  <li>The Field Map:
   <ul>
    <li>The first line defines the order of the fields, and what &quot;custom fields&quot; are defined in the file. Data can start on the second non-empty line, or after.</li>
    <li>Theres are the required fields: start time, end time, title, summary, and description.  Without defining these fields in the header the import will not proceed.  Required field names are not case sensitive.</li>
    <li>There is one optional column:: &quot;category&quot;.  If specified it can contain a ; separated list of category names that the event will belong to.</li>
   </ul>
  </li>
  <li>The Data Rows:
   <ul>
    <li>The start time, title, and description fields must not be empty.</li>
<li>Start and End Times:</li>
  <ul>
   <li>Start time processing is flexible.  You can specify either  YYYY-MM-DD HH:MM format, or many formats as defined by the strtotime function, including relative times.  If a relative time is supplied it is assumed to be relative to the current time.</li>
   <li>End time processing is flexible, and may be empty.  You can specify either an absolute time (in the same format as the start time) or a relative time.  If a relative time is specified, it is assumed to be relative to the start time.   i.e: &quot;+4 hours&quot; would indicate 4 hours from the start time column.</li>
   <li>If the end time colume is the string &quot;All day&quot; <em>(case insensitive)</em> it will assume an all day event from the start time.</li>
   <li>If the end time column is empty, then no end time value will be created in the database.</li>
  </ul>
</li>
<li>Categories
  <ul>
   <li>If specified, the category column can contain a list (separated by ;) of category names for which the event should belong.</li>
   <li>Category names are case sensitive.</li>
   <li>Categories are not created if they do not exist.</li>
  </ul>
</li>
<li>Custom Fields:
  <ul>
    <li>Custom field names (even in the first line that determines the field mapping) are case sensitive.</li>
    <li>Cutom fields are not created if specified in the CSV file.  Unknown custom field columns will be ignored.</li>
    <li>Custom fields of type &quot;file&quot; cannot be imported.  The entire import operation will fail.</li>
  </ul>
  </li>
  </ul>
</li>
<li>A sample csv file exists in the modules source code directory.</li>
</ul>';
$lang['prompt_csv_file'] = 'Die zu importierende Datei ausw&auml;hlen';
$lang['delete'] = 'L&ouml;schen';
$lang['cd_company'] = 'Firmenverzeichnis';
$lang['dflt_urlprefix'] = 'Voreingestelltes URL-Pr&auml;fix f&uuml;r Pretty URLs';
$lang['dflt_alldayevent'] = 'Neue Termine sollen voreingestellt ganzt&auml;gig sein';
$lang['dflt_starttime'] = 'Voreingestellte Startzeit f&uuml;r neue Termine';
$lang['info_dflt_starttime'] = '<em>(wird nur dann angewendet, wenn neue Termine keine ganzt&auml;tigen Termine sind.)</em>';
$lang['search_type'] = 'Such-Typ';
$lang['search_any'] = 'Gibt Ergebnisse zur&uuml;ck, wenn irgend ein Wort enthalten ist';
$lang['search_all'] = 'Gibt Ergebnisse zur&uuml;ck, wenn alle Worte enthalten sind';
$lang['info_customfields'] = '<strong style=&quot;color: red;&quot;>Hinweis:</strong> Felder zum Hochladen von Dateien k&ouml;nnen nicht durchsucht werden.';
$lang['searchable'] = 'Durchsuchbar';
$lang['help_param_editeventtemplate'] = 'Kann nur zusammen mit der Aktion &bdquo;myevents&ldquo; verwendet werden. Mit diesem Parameter kann ein von den Voreinstellungen abweichendes Template festgelegt werden, wenn ein Benutzer einen Termin erstellt oder bearbeitet';
$lang['help_param_editpage'] = 'Kann nur zusammen mit der Aktion myevents verwendet werden. Mit diesem Parameter kann eine von den Voreinstellungen abweichende Seite f&uuml;r das Bearbeitungsformular festgelegt werden.';
$lang['help_param_myeventstemplate'] = 'Kann nur zusammen mit der Aktion myevents verwendet werden. Mit diesem Parameter kann ein von den Voreinstellungen abweichendes Template festgelegt werden.';
$lang['cal_edit_event'] = 'Kalender-Eintrag bearbeiten';
$lang['error_dberror'] = 'Datenbankfehler';
$lang['submit'] = 'Absenden';
$lang['info_sysdflt_editevent_template'] = 'Voreingestelltes Template f&uuml;r &bdquo;Termin bearbeiten&ldquo;';
$lang['info_sysdflt_myevents_template'] = 'Voreingestelltes Template f&uuml;r &bdquo;Meine Termine&ldquo;';
$lang['prompt_feedit_group'] = 'Mitglieder dieser FEU-Gruppe d&uuml;rfen Termine hinzuf&uuml;gen';
$lang['prompt_feedit_page'] = 'Voreingestellte Seite f&uuml;r das Bearbeitungsformular auf der Webseite/Frontend';
$lang['none'] = 'Kein(e)/ohne Vorgabe';
$lang['owner'] = 'Eigent&uuml;mer';
$lang['cal_editevent_templates'] = 'Templates zum Bearbeiten von Termin-Formularen';
$lang['info_editevent_template_tab'] = 'Die Liste der Templates, die f&uuml;r die Bearbeitung von Termin-Formularen verf&uuml;gbar sind';
$lang['editeventtemplate_addedit'] = 'Ein Template zum Bearbeiten von Termin-Formularen hinzuf&uuml;gen/bearbeiten';
$lang['cal_myevents_templates'] = 'Meine Termin-Listen-Templates';
$lang['info_myevents_template_tab'] = 'Die Liste der Templates, die f&uuml;r die Anzeige einer Liste von Benutzerterminen verf&uuml;gbar sind';
$lang['myeventstemplate_addedit'] = 'Ein &quot;Meine Termine&quot;-Berichts-Template hinzuf&uuml;gen/bearbeiten';
$lang['areyousure_removeconflicting'] = 'Mit dieser Aktion werden alle Termine entfernt, die Konflikte mit Terminen hervorrufen, die nicht von anderen Terminen &uuml;berlappt werden d&uuml;rfen. Wollen Sie das wirklich?';
$lang['filter_conflicting'] = 'Konfliktbehaftete Termine filtern';
$lang['overlap_action_remove'] = 'Konfliktbehaftete Termine still entfernen';
$lang['overlap_action_error'] = 'Einen Fehler anzeigen';
$lang['prompt_overlap_action'] = 'Was soll passieren, wenn ein Konflikt beim Erstellen oder Bearbeiten eines Termins festgestellt wird?';
$lang['error_event_conflict'] = 'Die f&uuml;r den Termin eingegebenen Werte &uuml;berschneiden sich mit einem bereits existierenden Termin, der nicht &uuml;berlappt werden darf';
$lang['cal_info_overlap'] = 'Nur auf Termine mit einer Endzeit oder ganzt&auml;gigen Terminen anwenden';
$lang['cal_overlap'] = 'Neuen Terminen erlauben, sich mit diesen zu &uuml;berschneiden';
$lang['prompt_overlap_policy'] = 'Regel f&uuml;r Termin&uuml;berschneidungen';
$lang['policy_all'] = 'Alle Termine k&ouml;nnen sich &uuml;berschneiden';
$lang['policy_none'] = 'Kein Termin darf sich &uuml;berschneiden';
$lang['policy_individual'] = 'Soll f&uuml;r jeden Termin individuell festgelegt werden k&ouml;nnen';
$lang['lbl_back'] = 'Zur&uuml;ck';
$lang['lbl_templates'] = 'Templates ';
$lang['textarea'] = 'Textbereich';
$lang['error_calendar_incompatible'] = 'Es wurde festgestellt, dass das Modul &bdquo;Calendar&ldquo; ebenfalls installiert ist. Dieses Modul ist NICHT kompatibel mit dem Modul &bdquo;Calendar&ldquo; und kann auch NICHT gleichzeitig installiert sein. Bitte deinstallieren Sie das &bdquo;Calendar&ldquo;-Modul.';
$lang['error_event_not_found'] = 'Entweder ist die event_id nicht in der Datenbank vorhanden, oder es gibt mehrere Eintr&auml;ge mit dieser ID! (%d)';
$lang['first_page'] = '&amp;lt;&amp;lt;';
$lang['prev_page'] = '&amp;lt;';
$lang['next_page'] = '&amp;gt;';
$lang['last_page'] = '&amp;gt;&amp;gt;';
$lang['page_of'] = 'Seite %d von %d';
$lang['search_results'] = 'Kalender-Suchergebnisse';
$lang['search_words'] = 'Suchbegriffe';
$lang['no_results_found'] = 'Es wurden keine Ergebnisse zum angegebenen Suchbegriff gefunden';
$lang['frequency'] = 'Wiederholung';
$lang['specified_date'] = 'Ein bestimmtes Datum benutzen';
$lang['first_sunday'] = 'Erster Sonntag des Monats';
$lang['first_monday'] = 'Erster Montag des Monats';
$lang['first_tuesday'] = 'Erster Dienstag des Monats';
$lang['first_wednesday'] = 'Erster Mittwoch des Monats';
$lang['first_thursday'] = 'Erster Donnerstag des Monats';
$lang['first_friday'] = 'Erster Freitag des Monats';
$lang['first_saturday'] = 'Erster Samstag des Monats';
$lang['second_sunday'] = 'Zweiter Sonntag des Monats';
$lang['second_monday'] = 'Zweiter Montag des Monats';
$lang['second_tuesday'] = 'Zweiter Dienstag des Monats';
$lang['second_wednesday'] = 'Zweiter Mittwoch des Monats';
$lang['second_thursday'] = 'Zweiter Donnerstag des Monats';
$lang['second_friday'] = 'Zweiter Freitag des Monats';
$lang['second_saturday'] = 'Zweiter Samstag des Monats';
$lang['third_sunday'] = 'Dritter Sonntag des Monats';
$lang['third_monday'] = 'Dritter Montag des Monats';
$lang['third_tuesday'] = 'Dritter Dienstag des Monats';
$lang['third_wednesday'] = 'Dritter Mittwoch des Monats';
$lang['third_thursday'] = 'Dritter Donnerstag des Monats';
$lang['third_friday'] = 'Dritter Freitag des Monats';
$lang['third_saturday'] = 'Dritter Samstag des Monats';
$lang['fourth_sunday'] = 'Vierter Sonntag des Monats';
$lang['fourth_monday'] = 'Vierter Montag des Monats';
$lang['fourth_tuesday'] = 'Vierter Dienstag des Monats';
$lang['fourth_wednesday'] = 'Vierter Mittwoch des Monats';
$lang['fourth_thursday'] = 'Vierter Donnerstag des Monats';
$lang['fourth_friday'] = 'Vierter Freitag des Monats';
$lang['fourth_saturday'] = 'Vierter Samstag des Monats';
$lang['last_sunday'] = 'Letzter Sonntag des Monats';
$lang['last_monday'] = 'Letzter Montag des Monats';
$lang['last_tuesday'] = 'Letzter Dienstag des Monats';
$lang['last_wednesday'] = 'Letzter Mittwoch des Monats';
$lang['last_thursday'] = 'Letzter Donnerstag des Monats';
$lang['last_friday'] = 'Letzter Freitag des Monats';
$lang['last_saturday'] = 'Letzter Samstag des Monats';
$lang['error_invalid_recur_monthly_freq'] = 'Ung&uuml;ltige Wiederholung &ndash; ein bestimmtes Datum kann nicht zusammen mit anderen Werten angegeben werden';
$lang['searchresulttemplate_addedit'] = 'Ein Suchergebnis-Template hinzuf&uuml;gen/bearbeiten';
$lang['info_searchresult_template_tab'] = 'Eine Liste der Templates, die f&uuml;r die Anzeige der Suchergebnisse verf&uuml;gbar sind';
$lang['info_sysdflt_searchresult_template'] = 'Voreingestelltes Template f&uuml;r Suchergebnis';
$lang['cal_search_result_templates'] = 'Templates f&uuml;r Suchergebnisse';
$lang['error_query_failed'] = 'Datenbankabfrage fehlgeschlagen';
$lang['error_search_invalid_dates'] = 'Ung&uuml;ltige Suchdaten angegeben';
$lang['text'] = 'Text ';
$lang['search'] = 'Suche';
$lang['category'] = 'Kategorie';
$lang['info_sysdflt_search_template'] = 'Voreingestelltes Suchformular-Template';
$lang['searchtemplate_addedit'] = 'Ein Suchformular-Template hinzuf&uuml;gen/bearbeiten';
$lang['info_search_template_tab'] = 'Liste der Templates, die f&uuml;r die Anzeige des Suchformulars verf&uuml;gbar sind';
$lang['cal_search_form_templates'] = 'Suchformular-Templates';
$lang['max'] = 'maximal';
$lang['times'] = 'Mal';
$lang['on'] = 'an';
$lang['areyousure_uninstall'] = 'Wollen Sie das wirklich tun? In diesem Fall werden alle mit diesem Modul verbundenen Daten dauerhaft gel&ouml;scht.';
$lang['post_uninstall'] = 'Das Kalender-Modul wurde deinstalliert. S&auml;mtliche, in dem Modul vorhandenen Ereignisse und Templates wurden entfernt.';
$lang['fieldupdated'] = 'Feld aktualisiert';
$lang['every'] = 'Jeden';
$lang['or'] = 'oder';
$lang['update_children'] = 'Untergeordnete Ereignisse aktualisieren';
$lang['error_nocategory'] = 'Sie m&uuml;ssen mindestens eine Kategorie ausw&auml;hlen';
$lang['error_nothingselected'] = 'Es wurde nichts zum L&ouml;schen ausgew&auml;hlt';
$lang['error_eventoverlap'] = 'Die vorgegebenen Parameter f&uuml;r das Ereignis hat eine &Uuml;berschneidung von Ereignissen zur Folge.';
$lang['recurs'] = 'Wiederkehrend';
$lang['error_invalid_dates'] = 'Ein oder mehrere der eingegebenen Daten sind ung&uuml;ltig';
$lang['sunday'] = 'Sonntag';
$lang['monday'] = 'Montag';
$lang['tuesday'] = 'Dienstag';
$lang['wednesday'] = 'Mittwoch';
$lang['thursday'] = 'Donnerstag';
$lang['friday'] = 'Freitag';
$lang['saturday'] = 'Sonnabend';
$lang['abbr_sunday'] = 'So';
$lang['abbr_monday'] = 'Mo ';
$lang['abbr_tuesday'] = 'Di ';
$lang['abbr_wednesday'] = 'Mi ';
$lang['abbr_thursday'] = 'Do ';
$lang['abbr_friday'] = 'Fr ';
$lang['abbr_saturday'] = 'Sa ';
$lang['weekdays'] = 'Wochentage';
$lang['plural_daily'] = 'Tage';
$lang['plural_weekly'] = 'Wochen';
$lang['plural_monthly'] = 'Monate';
$lang['plural_yearly'] = 'Jahre';
$lang['no'] = 'Nein';
$lang['daily'] = 'T&auml;glich';
$lang['weekly'] = 'W&ouml;chentlich';
$lang['monthly'] = 'Monatlich';
$lang['yearly'] = 'J&auml;hrlich';
$lang['interval'] = 'Wiederholung';
$lang['cal_recur_details'] = 'Details zu wiederkehrenden Terminen';
$lang['unlimited'] = 'Unbeschr&auml;nkt';
$lang['max_recur_events'] = 'Maximale Anzahl von untergeordneten Terminen';
$lang['use_to_date'] = 'M&ouml;chten Sie ein abweichendes Enddatum eingeben?';
$lang['cancel'] = 'Abbrechen';
$lang['show_child_events'] = 'Untergeordnete Termine anzeigen <em>(das Ergebnis kann eine sehr lange Liste sein)</em>';
$lang['n/a'] = 'keine Angabe';
$lang['recurs_until'] = 'Wiederkehrend bis';
$lang['parent'] = '&Uuml;bergeordnet';
$lang['recur_period'] = 'H&auml;ufigkeit';
$lang['filter'] = 'Anzeige filtern';
$lang['start_date'] = 'Startdatum';
$lang['end_date'] = 'Enddatum';
$lang['info_upcominglist_template_tab'] = 'Liste der Templates, die f&uuml;r die Anzeige der Liste f&uuml;r zuk&uuml;nftige Termine verf&uuml;gbar sind';
$lang['upcominglisttemplate_addedit'] = 'Ein Template f&uuml;r die Anzeige einer Liste mit zuk&uuml;nftigen Terminen hinzuf&uuml;gen/bearbeiten';
$lang['info_sysdflt_upcominglist_template'] = 'Standard-Template f&uuml;r zuk&uuml;nftige Ereignisse';
$lang['info_list_template_tab'] = 'Die Liste der Templates, die f&uuml;r die Anzeige der Liste f&uuml;r Ereignisse verf&uuml;gbar sind';
$lang['listtemplate_addedit'] = 'Ein Template f&uuml;r die Anzeige von Listen hinzuf&uuml;gen/bearbeiten';
$lang['info_sysdflt_list_template'] = 'Standard-Listen-Template';
$lang['info_event_template_tab'] = 'Liste der Templates, die f&uuml;r die Anzeige der Terminen bereit stehen';
$lang['eventtemplate_addedit'] = 'Ein Template f&uuml;r die Anzeige von Terminen hinzuf&uuml;gen/bearbeiten';
$lang['info_sysdflt_event_template'] = 'Standard-Ereignis-Template';
$lang['info_calendar_template_tab'] = 'Die Liste der Templates, die f&uuml;r die Anzeige des Kalenders bereit stehen';
$lang['calendartemplate_addedit'] = 'Ein Template f&uuml;r die Anzeige eines Kalenders hinzuf&uuml;gen/bearbeiten';
$lang['info_sysdflt_calendar_template'] = 'Standard-Kalender-Template';
$lang['info_sysdflt_template'] = 'In diesem Formular k&ouml;nnen Templates festgelegt werden, die dann eingef&uuml;gt werden, wenn Sie in der jeweiligen Registerkarte auf &bdquo;Neues Template&ldquo; klicken. Hier vorgenommene &Auml;nderungen haben keine direkte Auswirkungen auf die Ausgabe dieses Moduls.';
$lang['eventdesc-EventAdded'] = 'Ausf&uuml;hren, nachdem ein Termin hinzuf&uuml;gt wurde';
$lang['eventdesc-EventEdited'] = 'Ausf&uuml;hren, nachdem ein Termin bearbeitet wurde';
$lang['eventdesc-EventDeleted'] = 'Ausf&uuml;hren, nachdem ein Termin gel&ouml;scht wurde';
$lang['eventdesc-CategoryAdded'] = 'Ausf&uuml;hren, nachdem eine Kategorie hinzugef&uuml;gt wurde';
$lang['eventdesc-CategoryEdited'] = 'Ausf&uuml;hren, nachdem eine Kategorie bearbeitet wurde';
$lang['eventdesc-CategoryDeleted'] = 'Ausf&uuml;hren, nachdem eine Kategorie gel&ouml;scht wurde';
$lang['eventhelp-EventAdded'] = '<p>Ausf&uuml;hren, wenn ein Termin hinzugef&uuml;gt wurde.</p>
<h4>Parameter</h4>
<table>
<tr>
<th>event_title</th>
<td>Name des Termins</td>
</tr>
<tr>
<th>event_summary</th>
<td>Zusammenfassung des Termins</td>
</tr>
<tr>
<th>event_details</th>
<td>Detaillierte Beschreibung</td>
</tr>
<tr>
<th>event_date_start</th>
<td>Startdatum/-zeit des Termins</td>
</tr>
<tr>
<th>event_date_end</th>
<td>Enddatum/-zeit des Termins</td>
</tr>
<tr>
<th>event_created_by</th>
<td>Benutzer-ID des Autors</td>
</tr>
<tr>
<th>event_id</th>
<td>ID des Termins</td>
</tr>
</table>
';
$lang['eventhelp-EventEdited'] = '<p>Ausf&uuml;hren, wenn ein Termin bearbeitet wurde.</p>
<h4>Parameter</h4>
<table>
<tr>
<th>event_title</th>
<td>Name des Termins</td>
</tr>
<tr>
<th>event_summary</th>
<td>Zusammenfassung des Termins</td>
</tr>
<tr>
<th>event_details</th>
<td>Detaillierte Beschreibung</td>
</tr>
<tr>
<th>event_date_start</th>
<td>Startdatum/-zeit des Termins</td>
</tr>
<tr>
<th>event_date_end</th>
<td>Enddatum/-zeit des Termins</td>
</tr>
<tr>
<th>event_created_by</th>
<td>Benutzer-ID des Autors</td>
</tr>
<tr>
<th>event_id</th>
<td>ID des Termins</td>
</tr>
</table>
';
$lang['eventhelp-EventDeleted'] = '<p>Ausf&uuml;hren, wenn ein Termin gel&ouml;scht wurde.</p>
<h4>Parameter</h4>
<table>
<tr>
<th>event_id</th>
<td>ID des Termins</td>
</tr>
</table>';
$lang['eventhelp-CategoryAdded'] = '<p>Ausf&uuml;hren, wenn eine Kalender-Kategorie hinzugef&uuml;gt wurde.</p>
<h4>Parameter</h4>
<table>
<tr>
<th>category_id</th>
<td>ID der Kategorie</td>
</tr>
</table>
';
$lang['eventhelp-CategoryEdited'] = '<p>Ausf&uuml;hren, wenn eine Kalender-Kategorie bearbeitet wurde.</p>
<h4>Parameter</h4>
<table>
<tr>
<th>category_id</th>
<td>ID der Kategorie</td>
</tr>
<tr>
<th>category_name</th>
<td>Name der Kategorie</td>
</tr>
<tr>
<th>category_order</th>
<td>Sortierung der Kategorie</td>
</tr>
</table>';
$lang['eventhelp-CategoryDeleted'] = '<p>Ausf&uuml;hren, wenn eine Kalender-Kategorie gel&ouml;scht wurde.</p>
<h4>Parameter</h4>
<table>
<tr>
<th>category_id</th>
<td>ID der Kategorie</td>
</tr>
<tr>
<th>category_name</th>
<td>Name der Kategorie</td>
</tr>
<tr>
<th>category_order</th>
<td>Sortierung der Kategorie</td>
</tr>
</table>
';
$lang['error_csv_insert'] = 'Fehler beim Importieren eines Termins in der CSV-Datei in Zeile %d';
$lang['error_csvfirstlinefldnotfound'] = 'Das Pflichtfeld %s konnte in der Kopfzeile der CSV nicht gefunden werden';
$lang['error_csvinvalidfirstline'] = 'In der CSV-Datei konnte keine g&uuml;ltige erste Zeile gefunden werden';
$lang['msg_eventadded'] = 'Termin hinzugef&uuml;gt';
$lang['error_noeventname'] = 'Sie m&uuml;ssen einen Namen f&uuml;r den Termin eingeben';
$lang['error_noupload'] = 'FEHLER: Es wurde keine hochgeladene Datei gefunden';
$lang['error_invalidfilename'] = 'FEHLER: Die hochgeladene Datei kann nicht akzeptiert werden';
$lang['error_problemwithupload'] = 'FEHLER: Beim Hochladen der Datei ist ein Fehler aufgetreten';
$lang['error_filecopyfailed'] = 'FEHLER: Beim Kopieren der Datei an den Zielort ist ein Fehler aufgetreten';
$lang['error_fileexists'] = 'FEHLER: Eine Datei mit diesem Namen existiert bereits';
$lang['error_csvfilenotfound'] = 'FEHLER: Konnte die CSV-Datei nicht finden';
$lang['error_cantopenfile'] = 'FEHLER: Konnte die Datei nicht &ouml;ffnen';
$lang['error_categoryexists'] = 'FEHLER: Eine Kategorie mit dem Namen %s existiert bereits';
$lang['cal_id'] = 'ID';
$lang['cal_calendar'] = 'Kalender (&bdquo;CGCalendar&ldquo;)';
$lang['cal_default_templates'] = 'Standard-Templates';
$lang['cal_description'] = 'Ein flexibles Modul, um Informationen &uuml;ber Termine in verschiedenen Formaten anzeigen.';
$lang['cal_addevent'] = 'Termin hinzuf&uuml;gen';
$lang['cal_import_events'] = 'Termine importieren';
$lang['cal_events'] = 'Termine';
$lang['cal_categories'] = 'Kategorien';
$lang['cal_calendar_template'] = 'Kalender-Template';
$lang['cal_list_template'] = 'Listen-Template';
$lang['cal_upcominglist_template'] = 'Template f&uuml;r bevorstehende Termine';
$lang['cal_event_template'] = 'Termin-Template';
$lang['cal_settings'] = 'Einstellungen';
$lang['cal_prev'] = '&lsaquo; zur&uuml;ck';
$lang['cal_next'] = 'weiter &rsaquo;';
$lang['cal_categories_updated'] = 'Kategorien aktualisiert';
$lang['cal_settings_updated'] = 'Einstellungen aktualisiert';
$lang['cal_add_event'] = 'Termin hinzuf&uuml;gen';
$lang['cal_edit'] = 'Bearbeiten';
$lang['cal_delete'] = 'L&ouml;schen';
$lang['cal_areyousure'] = 'Wollen Sie dies wirklich l&ouml;schen?';
$lang['cal_update_template'] = 'Template aktualisieren';
$lang['cal_sunday'] = 'Sonntag';
$lang['cal_monday'] = 'Montag';
$lang['cal_tuesday'] = 'Dienstag';
$lang['cal_wednesday'] = 'Mittwoch';
$lang['cal_thursday'] = 'Donnerstag';
$lang['cal_friday'] = 'Freitag';
$lang['cal_saturday'] = 'Samstag';
$lang['cal_sun'] = 'So';
$lang['cal_mon'] = 'Mo';
$lang['cal_tues'] = 'Di';
$lang['cal_wed'] = 'Mi';
$lang['cal_thurs'] = 'Do';
$lang['cal_fri'] = 'Fr';
$lang['cal_sat'] = 'Sa';
$lang['cal_january'] = 'Januar ';
$lang['cal_february'] = 'Februar ';
$lang['cal_march'] = 'M&auml;rz ';
$lang['cal_april'] = 'April ';
$lang['cal_may'] = 'Mai ';
$lang['cal_june'] = 'Juni ';
$lang['cal_july'] = 'Juli ';
$lang['cal_august'] = 'August ';
$lang['cal_september'] = 'September ';
$lang['cal_october'] = 'Oktober ';
$lang['cal_november'] = 'November ';
$lang['cal_december'] = 'Dezember ';
$lang['cal_add'] = 'Hinzuf&uuml;gen';
$lang['cal_update'] = 'Aktualisieren';
$lang['cal_event'] = 'Termin';
$lang['cal_date'] = 'Datum';
$lang['cal_summary'] = 'Zusammenfassung';
$lang['cal_details'] = 'Details ';
$lang['cal_more'] = 'mehr &raquo;';
$lang['cal_return'] = 'Zur&uuml;ck';
$lang['cal_to'] = 'bis';
$lang['cal_past_events'] = 'Vergangene Termine';
$lang['cal_upcoming_events'] = 'Bevorstehende Termine';
$lang['cal_any_category'] = 'Irgendeiner Kategorie';
$lang['cal_show_only_events_in'] = 'Nur Termine anzeigen aus';
$lang['cal_filter_by'] = 'Titel filtern mit <em>(regex)</em> ';
$lang['cal_go'] = 'Filtern';
$lang['cal_title'] = 'Titel';
$lang['cal_fromdate'] = 'Anfangsdatum';
$lang['cal_todate'] = 'Enddatum';
$lang['cal_update_categories'] = 'Kategorien aktualisieren';
$lang['cal_language'] = 'Sprache';
$lang['cal_updatesettings'] = 'Einstellungen aktualisieren';
$lang['cal_use_twelve_hour_clock'] = 'In den Listenmen&uuml;-Feldern die 12-Stunden-Anzeige verwenden?';
$lang['cal_default_category'] = 'Standard-Kategorie';
$lang['cal_update_fields'] = 'Felder aktualisieren';
$lang['force_category'] = 'F&uuml;r den Termin muss mindestens 1 Kategorie festgelegt werden';
$lang['showpastyears'] = 'Wieviele Jahre in die Vergangenheit sollen angezeigt werden';
$lang['showfutureyears'] = 'Wieviele Jahre in die Zukunft sollen angezeigt werden';
$lang['hidesummary'] = 'Die Anzeige des Zusammenfassungsfeldes deaktiveren (nur in der Administration)';
$lang['hidecontent'] = 'Die Anzeige des Detailfeldes deaktiveren (nur in der Administration)';
$lang['category_reminder'] = 'Bitte legen Sie eine oder mehrere Kategorien f&uuml;r diesen Termin fest.';
$lang['module_example_stylesheet'] = 'CSS-Beispiel f&uuml;r Calguys Kalender';
$lang['error_permission'] = 'Sie ben&ouml;tigen die Berechtigung %s, um diese Funktion nutzen zu k&ouml;nnen.';
$lang['install_postmessage'] = 'Stellen Sie sicher, dass die Benutzer, die die Termine im Kalender verwalten, die Berechtigung &bdquo;Modify Calendar&ldquo; haben.';
$lang['deletetagged'] = 'Markierte Termine l&ouml;schen';
$lang['confirmdeletetagged'] = 'Wollen Sie diese Termine wirklich l&ouml;schen?';
$lang['taggeddeleted'] = 'Die markierten Termine wurden gel&ouml;scht';
$lang['templates'] = 'Templates ';
$lang['template_help'] = 'Template-Hilfe';
$lang['file_templates'] = 'Datei-Templates';
$lang['addtemplate'] = 'Template hinzuf&uuml;gen';
$lang['template'] = 'Template ';
$lang['templatenametext'] = 'Template-Name';
$lang['edittemplate'] = 'Template bearbeiten';
$lang['deletetemplate'] = 'Template l&ouml;schen';
$lang['newtemplate'] = 'Neuer Template-Name';
$lang['templatenameexists'] = 'Fehler: Ein Template mit diesem Namen existiert bereits. Bitte w&auml;hlen Sie einen anderen Namen.';
$lang['templateimported'] = 'Das Template wurde erfolgreich in die Datenbank importiert und steht nun zur weiteren Verwendung bereit.';
$lang['view_default_stylesheet'] = 'Standard-Stylesheet anzeigen';
$lang['filename'] = 'Dateiname';
$lang['importtemplate'] = 'Template importieren';
$lang['template_deleted'] = 'Das Template wurde aus der Datenbank gel&ouml;scht.';
$lang['updatetemplatesuccess'] = 'Das Template wurde aktualisiert.';
$lang['updatetemplatefailure'] = 'Beim Aktualisieren des Templates ist ein Fehler aufgetreten.';
$lang['settingssaved'] = 'Die Einstellungen wurden erfolgreich gespeichert.';
$lang['categorydeleted'] = 'Kategorie gel&ouml;scht';
$lang['categoryupdated'] = 'Kategorie aktualisiert';
$lang['categoryadded'] = 'Kategorie hinzugef&uuml;gt';
$lang['eventdeleted'] = 'Der Termin wurde gel&ouml;scht.';
$lang['eventupdated'] = 'Der Termin wurde aktualisiert.';
$lang['default_page_error'] = 'FEHLER: Um das Kalender-Modul mit der Funktion &bdquo;Pretty URL&ldquo; nutzen zu k&ouml;nnen, muss eine Standardseite festgelegt werden. Gehen Sie daf&uuml;r in die Registerkarte &bdquo;Einstellungen&ldquo; und w&auml;hlen dort eine Seite aus.';
$lang['time_at'] = 'am';
$lang['type'] = 'Typ';
$lang['name'] = 'Name ';
$lang['order'] = 'Sortierung';
$lang['fieldadded'] = 'Das Feld wurde erfolgreich hinzugef&uuml;gt';
$lang['fielddeleted'] = 'Das Feld wurde gel&ouml;scht';
$lang['fields'] = 'Benutzerdefinierte Felder';
$lang['textfield'] = 'Textfeld';
$lang['uploadfield'] = 'Feld zum Hochladen von Datei';
$lang['description'] = '<p>Mit dem Kalender-Modul k&ouml;nnen Terminen auf Ihrer Webseite angezeigt werden. Nach der Installation k&ouml;nnen Sie in der Administration &uuml;ber das Men&uuml; &bdquo;Inhalte > Kalender&ldquo; Ihre Termine/Ereignisse verwalten.</p>';
$lang['defaultcalendarpage'] = 'Standardseite, auf der das Kalender-Modul angezeigt wird. (Diese Seite muss den Smarty-Tag zum Aufruf des Kalender-Moduls enthalten. Wenn Sie die Funktion &bdquo;Pretty URL&ldquo; nutzen wollen, ist diese Einstellung zwingend erforderlich.)';
$lang['uploaddirectory'] = 'Verzeichnis, in dem die hochgeladenen Dateien abgelegt werden sollen';
$lang['uploadfiletypes'] = 'Erlaubte Dateitypen';
$lang['uploadunique'] = 'Auf eindeutige Dateinamen achten';
$lang['thumb_width'] = 'Breite des Vorschaubildes';
$lang['thumb_height'] = 'H&ouml;he des Vorschaubildes';
$lang['large_width'] = 'Breite des gro&szlig;en Bildes';
$lang['large_height'] = 'H&ouml;he des gro&szlig;en Bildes';
$lang['cal_recur_period'] = 'Wiederholen';
$lang['cal_recur_until'] = 'Wiederholen bis';
$lang['help_template'] = '<p><strong>Name des Autors ausgeben:</strong></p>
<code>Autor: {$event.authorname}</code>
';
?>
